pub fn text_scale(resolved: &ResolvedThemeVariant) -> &ResolvedTextScaleExpand description
Access the text scale entries from the resolved theme.
Returns the 4-entry text scale (caption, section_heading, dialog_title, display).
pub fn text_scale(resolved: &ResolvedThemeVariant) -> &ResolvedTextScaleAccess the text scale entries from the resolved theme.
Returns the 4-entry text scale (caption, section_heading, dialog_title, display).